@@ -1,5 +1,27 @@
-//      LAPACK++ (V. 1.1)
-//      (C) 1992-1996 All Rights Reserved.
+// -*- c++ -*-
+//              LAPACK++ 1.1 Linear Algebra Package 1.1
+//               University of Tennessee, Knoxvilee, TN.
+//            Oak Ridge National Laboratory, Oak Ridge, TN.
+//        Authors: J. J. Dongarra, E. Greaser, R. Pozo, D. Walker
+//                 (C) 1992-1996 All Rights Reserved
+//
+//                             NOTICE
+//
+// Permission to use, copy, modify, and distribute this software and
+// its documentation for any purpose and without fee is hereby granted
+// provided that the above copyright notice appear in all copies and
+// that both the copyright notice and this permission notice appear in
+// supporting documentation.
+//
+// Neither the Institutions (University of Tennessee, and Oak Ridge National
+// Laboratory) nor the Authors make any representations about the suitability 
+// of this software for any purpose.  This software is provided ``as is'' 
+// without express or implied warranty.
+//
+// LAPACK++ was funded in part by the U.S. Department of Energy, the
+// National Science Foundation and the State of Tennessee.
+//
+// Modifications Copyright (C) 2000-2000 the R Development Core Team
 
 
 #ifndef _LA_COL_VECTOR_DOUBLE_H_
@@ -32,14 +54,14 @@ public:
 
     inline LaColVectorDouble& ref(const LaGenMatDouble &);
     LaColVectorDouble& ref(SEXP);
-    inline LaColVectorDouble& inject(const LaGenMatDouble &);
-    inline LaColVectorDouble& copy(const LaGenMatDouble &);
+    inline LaColVectorDouble& inject(const LaMatDouble &);
+    inline LaColVectorDouble& copy(const LaMatDouble &);
     
     inline double& operator()(int i);
     inline const double& operator()(int i) const ;
     inline LaColVectorDouble operator()(const LaIndex&);
 
-    inline LaColVectorDouble& operator=(const LaGenMatDouble &A);
+    inline LaColVectorDouble& operator=(const LaMatDouble &A);
     inline LaColVectorDouble& operator=(double d);
     
 };
@@ -82,7 +104,7 @@ inline LaColVectorDouble LaColVectorDouble::operator()(const LaIndex& I)
     return LaGenMatDouble::operator()(I,LaIndex(0,0)); 
 }
 
-inline LaColVectorDouble& LaColVectorDouble::operator=(const LaGenMatDouble &A)
+inline LaColVectorDouble& LaColVectorDouble::operator=(const LaMatDouble &A)
 {
     LaGenMatDouble::copy(A);
     return *this;
@@ -94,7 +116,7 @@ inline LaColVectorDouble& LaColVectorDouble::operator=(double d)
     return *this;
 }
 
-inline LaColVectorDouble& LaColVectorDouble::copy(const LaGenMatDouble &A)
+inline LaColVectorDouble& LaColVectorDouble::copy(const LaMatDouble &A)
 {
     assert(A.size(1) == 1);   //make sure A is a column vector.
     LaGenMatDouble::copy(A);
@@ -109,7 +131,7 @@ inline LaColVectorDouble& LaColVectorDouble::ref(const LaGenMatDouble &A)
     return *this;
 }
 
-inline LaColVectorDouble& LaColVectorDouble::inject(const LaGenMatDouble &A)
+inline LaColVectorDouble& LaColVectorDouble::inject(const LaMatDouble &A)
 {
     assert(A.size(0) == 1 || A.size(1) == 1);
     LaGenMatDouble::inject(A);
