@@ -25,3 +25,20 @@
 
 #include "lafnames.h"
 #include LA_SPD_MAT_DOUBLE_H
+
+SEXP LaSpdMatDouble::asSEXP() const
+{
+    int n = size(0);
+    SEXP val = allocMatrix(REALSXP, n, n);
+    F77_CALL(dlacpy)('L', n, n, &(*this)(0,0), gdim(0),
+		     REAL(val), n);
+    for (int i = 1; i < n; i++) // symmetrize the result
+	for (int j = 0; j < i; j++)
+	    REAL(val)[i * n + j] = REAL(val)[j * n + i];
+    SEXP classes = allocVector(STRSXP, 3);
+    STRING(classes)[0] = mkChar("PositiveDefinite");
+    STRING(classes)[1] = mkChar("Hermitian");
+    STRING(classes)[2] = mkChar("Matrix");
+    setAttrib(val, R_ClassSymbol, classes);
+    return val;
+}
